<?php
$page_title = "管理者操作ログ";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					<div class="btns">
						<input type="button" id="btnSearch" value="Search" class="btn bg-default px50 hi22">
					</div>
				</div>
				<form id="searchForm" action="" method="post">
					<table class="conditions fontS w100p">
						<tr>
							<th>操作内容</th>
							<td><input type="text" id="name" name="name" value="<?php $this -> echoName(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>Activity</th>
							<td><input type="text" id="details" name="details" value="<?php $this -> echoDetails(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>IPアドレス</th>
							<td><input type="text" id="ip_address" name="ip_address" value="<?php $this -> echoIp(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">Category</span>
								<?php $this -> dispStatuses(); ?>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">Processing Date</span>
								<?php $this -> dispOpenFlg(); ?>
								<input type="text" id="from" name="from" value="<?php $this -> echoFrom(); ?>" class="px110"> - <input type="text" id="to" name="to" value="<?php $this -> echoTo(); ?>" class="px110">
							</td>
						</tr>
					</table>
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<form id="searchForm" action="" method="post">
							</form>
							<?php $this -> dispPager(); ?>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th class="w10p">処理日時</th>
									<th class="w10p">操作内容</th>
									<th class="w10p">管理者名</th>
									<th class="w10p">IPアドレス</th>
									<th class="w10p">ユーザーエージェント</th>
									<th class="w50p">Activity</th>
								</tr>
								<?php $this -> echoList(); ?>
							</table>

							<input type="hidden" value="action" id="type" name="type" />
							<input type="hidden" value="withdraw" name="action" />
							<input type="hidden" id="w_id" name="w_id" />
							<input type="hidden" id="detail_account" name="detail_account" />
						</form>
						<div class="article-bottom">
							<?php $this -> dispPager(); ?>
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="js/admin_log.js"></script>
</body>
</html>
